@@ -9,7 +9,7 @@ use Net::Whois::Norid;
 
 $Net::Whois::Raw::CHECK_FAIL = 1;
 
-use version; our $VERSION = qv('0.6.0');
+use version; our $VERSION = qv('0.6.1');
 
 use parent qw/Exporter/;
 our @EXPORT_OK = qw/all domain2orgnr orgnr_ok orgnr2domains/;
@@ -76,7 +76,7 @@ No::OrgNr - Utility functions for Norwegian organizations' ID numbers
 
 =head1 VERSION
 
-This document describes No::OrgNr version 0.6.0
+This document describes No::OrgNr version 0.6.1
 
 
 =head1 SYNOPSIS
@@ -156,13 +156,51 @@ Documentation for this module is available using the perldoc command:
 
     perldoc No::OrgNr
 
+The following sites may be useful:
+
+=over 4
+
+=item *
+
+AnnoCPAN: L<http://annocpan.org/dist/No-OrgNr>
+
+=item *
+
+MetaCPAN: L<https://metacpan.org/pod/No::OrgNr>
+
+=item *
+
+CPAN Dependencies: L<http://deps.cpantesters.org/?module=No%3A%3AOrgNr>
+
+=item *
+
+CPAN Ratings: L<http://cpanratings.perl.org/dist/No::OrgNr>
+
+=item *
+
+CPAN Search: L<http://search.cpan.org/perldoc?No::OrgNr>
+
+=item *
+
+CPAN Testers Matrix: L<http://matrix.cpantesters.org/?dist=No-OrgNr>
+
+=item *
+
+CPAN Testers Reports: L<http://www.cpantesters.org/distro/N/No-OrgNr.html>
+
+=item *
+
+CPANTS (CPAN Testing Service): L<http://cpants.cpanauthors.org/dist/No-OrgNr>
+
+=back
+
 =head1 AUTHOR
 
-Geir Myklebust C<< <geirmy@gmail.com> >>
+Geir Myklebust C<< <geirmy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 Geir Myklebust C<< <geirmy@gmail.com> >>.
+Copyright 2015 Geir Myklebust C<< <geirmy@cpan.org> >>.
 
 This module is free software; you can redistribute it and/or modify it under the same terms as Perl
 itself. See L<Perl Artistic License|perlartistic>.
